package com.lantone.qc.kernel.structure.ai;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.lantone.qc.kernel.client.CRFServiceClient;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.entity.Annotation;
import com.lantone.qc.pub.model.vo.CRFVo;
import com.lantone.qc.pub.util.StringUtil;

/**
 * @ClassName : ModelAI
 * @Description : 算法基类
 * @Author : 楼辉荣
 * @Date: 2020-03-19 15:08
 */
public class ModelAI {
    /**
     * 获取CRF返回数据
     *
     * @param crfContent
     * @param crfServiceClient
     * @return
     */
    protected JSONObject loadAI(JSONArray crfContent, CRFServiceClient crfServiceClient) {
        //存储CRF完整所需结构数据
        CRFVo crfVo = new CRFVo();
        crfVo.setData(crfContent);
        //获取CRF模型返回数据
        JSONArray data = getAnnotation(crfServiceClient, crfVo).getData();
        JSONObject midData = getOutputs(data);
        return midData;
    }

    protected JSONObject loadEntity(JSONObject jsonObject, String entityRelationObject, String outputs) {
        if(jsonObject ==null) {
            return new JSONObject();
        }
        JSONObject aiOut = jsonObject.getJSONObject(entityRelationObject).getJSONObject(outputs);
        return aiOut;
    }

    private Annotation getAnnotation(CRFServiceClient crfServiceClient, CRFVo crfVo) {
        Annotation annotation = new Annotation();
        try {
            String annotation_str = crfServiceClient.getAnnotation(crfVo);
            annotation = JSON.parseObject(annotation_str, Annotation.class);
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {
            return annotation;
        }
    }

    protected void putContent(JSONArray crfContent, String medicalTextType, String text, String sign) {
        String move_text = CatalogueUtil.removeSpecialChar(text);
        if (StringUtil.isEmpty(move_text)) {
            return;
        }
        JSONObject detailContent = new JSONObject();
        detailContent.put("medical_text_type", medicalTextType);
        detailContent.put("content", move_text);
        detailContent.put("detail_title", sign);
        crfContent.add(detailContent);
    }

    protected void putContent(JSONArray crfContent, String medicalTextType, String firstText, String secondText, String sign) {
        String firstMoveText = CatalogueUtil.removeSpecialChar(firstText);
        String secondMoveText = CatalogueUtil.removeSpecialChar(secondText);
        if (StringUtil.isEmpty(firstMoveText) && StringUtil.isEmpty(secondMoveText)) {
            return;
        }
        JSONObject detailContent = new JSONObject();
        detailContent.put("medical_text_type", medicalTextType);
        detailContent.put("content", firstMoveText + "\n" + secondMoveText);
        detailContent.put("detail_title", sign);
        crfContent.add(detailContent);
    }

    /**
     * 获取CRF模型输出并处理
     *
     * @param data
     * @return
     */
    public JSONObject getOutputs(JSONArray data) {
        JSONObject midData = new JSONObject();
        for (int i = 0; i < data.size(); i++) {
            JSONObject detailContent = data.getJSONObject(i);
            String detail_title = detailContent.getString("detail_title");
            if (StringUtil.isNotEmpty(detail_title) && midData.get(detail_title) == null) {
                midData.put(detail_title, detailContent);
            }
        }
        return midData;
    }
}