package com.lantone.qc.trans.comsis;

import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.ClinicalBloodDoc;
import com.lantone.qc.pub.model.doc.ConsultationDoc;
import com.lantone.qc.pub.model.doc.DeathCaseDiscussDoc;
import com.lantone.qc.pub.model.doc.DeathRecordDoc;
import com.lantone.qc.pub.model.doc.DifficultCaseDiscussDoc;
import com.lantone.qc.pub.model.doc.DutyShiftSystemDoc;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.LeaveHospitalDoc;
import com.lantone.qc.pub.model.doc.NursingSystemDoc;
import com.lantone.qc.pub.model.doc.OperationDiscussionDoc;
import com.lantone.qc.pub.model.doc.PreoperativeDiscussionDoc;
import com.lantone.qc.pub.model.doc.RescueDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.model.label.ChiefLabel;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.label.FamilyLabel;
import com.lantone.qc.pub.model.label.MaritalLabel;
import com.lantone.qc.pub.model.label.MenstrualLabel;
import com.lantone.qc.pub.model.label.PacsLabel;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.model.label.PersonalLabel;
import com.lantone.qc.pub.model.label.PresentLabel;
import com.lantone.qc.pub.model.label.VitalLabel;
import com.lantone.qc.pub.model.label.VitalLabelSpecial;

import java.util.Map;

/**
 * 各个模块文档生成，各地公用
 *
 * @Description:
 * @author: rengb
 * @time: 2020/3/6 10:15
 */
public class ModelDocGenerate {

    /**
     * 入院记录
     *
     * @param structureMap
     * @return
     */
    public static BeHospitalizedDoc beHospitalizedDocGen(Map<String, String> structureMap) {
        BeHospitalizedDoc beHospitalizedDoc = new BeHospitalizedDoc();

        ChiefLabel chiefLabel = new ChiefLabel();
        chiefLabel.setText(structureMap.get("主诉"));
        beHospitalizedDoc.setChiefLabel(chiefLabel);
        structureMap.remove("主诉");

        PresentLabel presentLabel = new PresentLabel();
        presentLabel.setText(structureMap.get("现病史"));
        beHospitalizedDoc.setPresentLabel(presentLabel);
        structureMap.remove("现病史");

        PastLabel pastLabel = new PastLabel();
        pastLabel.setText(structureMap.get("既往史"));
        beHospitalizedDoc.setPastLabel(pastLabel);
        structureMap.remove("既往史");

        PersonalLabel personalLabel = new PersonalLabel();
        personalLabel.setText(structureMap.get("个人史"));
        beHospitalizedDoc.setPersonalLabel(personalLabel);
        structureMap.remove("个人史");

        MaritalLabel maritalLabel = new MaritalLabel();
        maritalLabel.setText("婚育史: " + structureMap.get("婚育史"));
        beHospitalizedDoc.setMaritalLabel(maritalLabel);
        structureMap.remove("婚育史");

        MenstrualLabel menstrualLabel = new MenstrualLabel();
        menstrualLabel.setText("月经史:" + structureMap.get("月经史"));
        beHospitalizedDoc.setMenstrualLabel(menstrualLabel);
        structureMap.remove("月经史");

        FamilyLabel familyLabel = new FamilyLabel();
        familyLabel.setText(structureMap.get("家族史"));
        beHospitalizedDoc.setFamilyLabel(familyLabel);
        structureMap.remove("家族史");

        VitalLabel vitalLabel = new VitalLabel();
        vitalLabel.setText(structureMap.get("体格检查"));
        beHospitalizedDoc.setVitalLabel(vitalLabel);
        structureMap.remove("体格检查");

        VitalLabelSpecial vitalLabelSpecial = new VitalLabelSpecial();
        vitalLabelSpecial.setText(structureMap.get("专科体格检查"));
        beHospitalizedDoc.setVitalLabelSpecial(vitalLabelSpecial);
        structureMap.remove("专科体格检查");

        PacsLabel pacsLabel = new PacsLabel();
        pacsLabel.setText(structureMap.get("辅助检查"));
        beHospitalizedDoc.setPacsLabel(pacsLabel);
        structureMap.remove("辅助检查");

        DiagLabel initialDiagLabel = new DiagLabel();
        initialDiagLabel.setText(structureMap.get("初步诊断"));
        beHospitalizedDoc.setInitialDiagLabel(initialDiagLabel);
        structureMap.remove("初步诊断");

        DiagLabel revisedDiagLabel = new DiagLabel();
        revisedDiagLabel.setText(structureMap.get("修正诊断"));
        beHospitalizedDoc.setRevisedDiagLabel(revisedDiagLabel);
        structureMap.remove("修正诊断");

        DiagLabel suppleDiagLabel = new DiagLabel();
        suppleDiagLabel.setText(structureMap.get("补充诊断"));
        beHospitalizedDoc.setSuppleDiagLabel(suppleDiagLabel);
        structureMap.remove("补充诊断");

        beHospitalizedDoc.setStructureMap(structureMap);

        return beHospitalizedDoc;
    }

    /**
     * 输血/血制品病程记录
     *
     * @param structureMap
     * @return
     */
    public static ClinicalBloodDoc clinicalBloodDocGen(Map<String, String> structureMap) {
        ClinicalBloodDoc clinicalBloodDoc = new ClinicalBloodDoc();
        clinicalBloodDoc.setStructureMap(structureMap);
        return clinicalBloodDoc;
    }

    /**
     * 会诊记录
     *
     * @param structureMap
     * @return
     */
    public static ConsultationDoc consultationDocGen(Map<String, String> structureMap) {
        ConsultationDoc consultationDoc = new ConsultationDoc();
        consultationDoc.setStructureMap(structureMap);
        return consultationDoc;
    }

    /**
     * 死亡病例讨论记录
     *
     * @param structureMap
     * @return
     */
    public static DeathCaseDiscussDoc deathCaseDiscussDocGen(Map<String, String> structureMap) {
        DeathCaseDiscussDoc deathCaseDiscussDoc = new DeathCaseDiscussDoc();
        deathCaseDiscussDoc.setStructureMap(structureMap);
        return deathCaseDiscussDoc;
    }

    /**
     * 死亡记录
     *
     * @param structureMap
     * @return
     */
    public static DeathRecordDoc deathRecordDocGen(Map<String, String> structureMap) {
        DeathRecordDoc deathRecordDoc = new DeathRecordDoc();
        deathRecordDoc.setStructureMap(structureMap);
        return deathRecordDoc;
    }

    /**
     * 疑难病例讨论记录
     *
     * @param structureMap
     * @return
     */
    public static DifficultCaseDiscussDoc difficultCaseDiscussDocGen(Map<String, String> structureMap) {
        DifficultCaseDiscussDoc difficultCaseDiscussDoc = new DifficultCaseDiscussDoc();
        difficultCaseDiscussDoc.setStructureMap(structureMap);
        return difficultCaseDiscussDoc;
    }

    /**
     * 值班交接制度
     *
     * @param structureMap
     * @return
     */
    public static DutyShiftSystemDoc dutyShiftSystemDocGen(Map<String, String> structureMap) {
        DutyShiftSystemDoc dutyShiftSystemDoc = new DutyShiftSystemDoc();
        dutyShiftSystemDoc.setStructureMap(structureMap);
        return dutyShiftSystemDoc;
    }

    /**
     * 首次病程录
     *
     * @param structureMap
     * @return
     */
    public static FirstCourseRecordDoc firstCourseRecordDocGen(Map<String, String> structureMap) {
        FirstCourseRecordDoc firstCourseRecordDoc = new FirstCourseRecordDoc();
        firstCourseRecordDoc.setStructureMap(structureMap);
        return firstCourseRecordDoc;
    }

    /**
     * 出院小结
     *
     * @param structureMap
     * @return
     */
    public static LeaveHospitalDoc leaveHospitalDocGen(Map<String, String> structureMap) {
        LeaveHospitalDoc leaveHospitalDoc = new LeaveHospitalDoc();

        DiagLabel beDiagLabel = new DiagLabel();
        beDiagLabel.setText(structureMap.get("入院诊断"));
        leaveHospitalDoc.setBeHospitalizedLabel(beDiagLabel);
        structureMap.remove("入院诊断");

        DiagLabel leaveDiagLabel = new DiagLabel();
        leaveDiagLabel.setText(structureMap.get("出院诊断"));
        leaveHospitalDoc.setLeaveDiagLabel(leaveDiagLabel);
        structureMap.remove("出院诊断");

        leaveHospitalDoc.setStructureMap(structureMap);

        return leaveHospitalDoc;
    }

    /**
     * 分级护理制度
     *
     * @param structureMap
     * @return
     */
    public static NursingSystemDoc nursingSystemDocGen(Map<String, String> structureMap) {
        NursingSystemDoc nursingSystemDoc = new NursingSystemDoc();
        nursingSystemDoc.setStructureMap(structureMap);
        return nursingSystemDoc;
    }

    /**
     * 术后首次病程及谈话记录
     *
     * @param structureMap
     * @return
     */
    public static OperationDiscussionDoc operationDiscussionDocGen(Map<String, String> structureMap) {
        OperationDiscussionDoc operationDiscussionDoc = new OperationDiscussionDoc();
        operationDiscussionDoc.setStructureMap(structureMap);
        return operationDiscussionDoc;
    }

    /**
     * 术前讨论、术前小结
     *
     * @param structureMap
     * @return
     */
    public static PreoperativeDiscussionDoc preoperativeDiscussionDocGen(Map<String, String> structureMap) {
        PreoperativeDiscussionDoc preoperativeDiscussionDoc = new PreoperativeDiscussionDoc();
        preoperativeDiscussionDoc.setStructureMap(structureMap);
        return preoperativeDiscussionDoc;
    }

    /**
     * 抢救记录
     *
     * @param structureMap
     * @return
     */
    public static RescueDoc rescueDocGen(Map<String, String> structureMap) {
        RescueDoc rescueDoc = new RescueDoc();
        rescueDoc.setStructureMap(structureMap);
        return rescueDoc;
    }

    /**
     * 查房记录
     *
     * @param structureMap
     * @return
     */
    public static ThreeLevelWardDoc threeLevelWardDocGen(Map<String, String> structureMap) {
        ThreeLevelWardDoc threeLevelWardDoc = new ThreeLevelWardDoc();
        threeLevelWardDoc.setStructureMap(structureMap);
        return threeLevelWardDoc;
    }

}